@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 use WebService::Simple;
-use YAML;
+use Data::Dumper;
 use utf8;
 binmode STDOUT, ":utf8";
 
-my $api_key = "your_api_key";
+my $api_key = $ARGV[0] || "your_api_key";
 
 my $flickr = WebService::Simple->new(
     base_url => "http://api.flickr.com/services/rest/",
@@ -13,5 +13,5 @@ my $flickr = WebService::Simple->new(
 );
 
 my $response =
-  $flickr->get( { method => "flickr.photos.search", text => "富士山" } );
-print Dump $response->parse_xml;
+  $flickr->get( { method => "flickr.photos.search", text => "cat" } );
+print Dumper $response->parse_response;
